#!/bin/bash

for x in `cat files.in`
do
    g++ -c $x
done
